@@ -36,12 +36,14 @@ from __future__ import absolute_import
 
 import base64
 import inspect
+from logging import getLogger
 
 import univention.admin.uexceptions
-import univention.debug as ud
 from univention.admin import localization
 
 
+log = getLogger('ADMIN')
+
 translation = localization.translation('univention/admin')
 
 _ = translation.translate
@@ -134,7 +136,7 @@ def ListUniq(list):
 
 
 def ListToString(value, encoding=()):
-    # type: (List[str]) -> str
+    # type: (List[bytes]) -> str
     """
     Return first element from list.
     This is right mapping for single-valued properties, as |LDAP| always returns lists of values.
@@ -154,7 +156,7 @@ def ListToString(value, encoding=()):
 
 
 def ListToIntToString(list_):
-    # type: (List[str]) -> str
+    # type: (List[bytes]) -> str
     """
     Return first element from list if it is an integer.
 
@@ -177,7 +179,7 @@ def ListToIntToString(list_):
 
 
 def ListToLowerString(list):
-    # type: (List[str]) -> str
+    # type: (List[bytes]) -> str
     """
     Return first element from list lower-cased.
 
@@ -225,7 +227,7 @@ def nothing(a):
 
 
 def IgnoreNone(value, encoding=()):
-    # type: (str) -> Union[None, str]
+    # type: (str) -> Union[None, bytes]
     """
     Return the value if it is not the string `None`.
 
@@ -242,7 +244,7 @@ def IgnoreNone(value, encoding=()):
 
 
 def _stringToInt(value):
-    # type: (str) -> int
+    # type: (Union[bytes, str]) -> int
     """
     Try to convert string into integer.
 
@@ -261,7 +263,7 @@ def _stringToInt(value):
 
 
 def unmapUNIX_TimeInterval(value):
-    # type: (Union[List[str], Tuple[str], str]) -> List[Text]
+    # type: (Union[List[bytes], Tuple[bytes], bytes]) -> List[Text]
     """
     Map number of seconds to a human understandable time interval.
 
@@ -296,7 +298,7 @@ def unmapUNIX_TimeInterval(value):
 
 
 def mapUNIX_TimeInterval(value):
-    # type: (Union[List[str], Tuple[str], str]) -> Text
+    # type: (Union[List[str], Tuple[str], str]) -> bytes
     """
     Unmap a human understandable time interval back to number of seconds.
 
@@ -345,12 +347,12 @@ def unmapBase64(value):
         try:
             return [base64.b64encode(x).decode('ASCII') for x in value]
         except Exception as e:
-            ud.debug(ud.ADMIN, ud.ERROR, 'ERROR in unmapBase64: %s' % e)
+            log.error('ERROR in unmapBase64: %s', e)
     else:
         try:
             return base64.b64encode(value[0]).decode('ASCII')
         except Exception as e:
-            ud.debug(ud.ADMIN, ud.ERROR, 'ERROR in unmapBase64: %s' % e)
+            log.error('ERROR in unmapBase64: %s', e)
     return ""
 
 
@@ -378,17 +380,17 @@ def mapBase64(value):
         try:
             return [base64.b64decode(x) for x in value]
         except Exception as e:
-            ud.debug(ud.ADMIN, ud.ERROR, 'ERROR in mapBase64: %s' % e)
+            log.error('ERROR in mapBase64: %s', e)
     else:
         try:
             return base64.b64decode(value)
         except Exception as e:
-            ud.debug(ud.ADMIN, ud.ERROR, 'ERROR in mapBase64: %s' % e)
+            log.error('ERROR in mapBase64: %s', e)
     return ""
 
 
 def BooleanListToString(list, encoding=()):
-    # type: (List[str]) -> str
+    # type: (List[bytes]) -> str
     """
     Convert |LDAP| boolean to |UDM|.
 
@@ -407,7 +409,7 @@ def BooleanListToString(list, encoding=()):
 
 
 def BooleanUnMap(value, encoding=()):
-    # type: (str) -> str
+    # type: (str) -> bytes
     """
     Convert |UDM| boolean to |LDAP|.
 
@@ -555,7 +557,7 @@ class mapping(object):
         errors = encoding_errors or errors
         value = self.mapValue(map_name, value, encoding_errors=errors)
         if isinstance(value, (list, tuple)):
-            ud.debug(ud.ADMIN, ud.WARN, 'mapValueDecoded returns a list for %s. This is probably not wanted?' % map_name)
+            log.warning('mapValueDecoded returns a list for %s. This is probably not wanted?', map_name)
             value = [val.decode(encoding, errors) for val in value]
         else:
             value = value.decode(encoding, errors)
